@@ -14,32 +14,31 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "colourpopup.h"
+#include "colourpopup.hpp"
 
 namespace pv {
 namespace widgets {
 
 ColourPopup::ColourPopup(int rows, int cols, QWidget *parent) :
 	Popup(parent),
-	_well_array(rows, cols, this),
-	_layout(this)
+	well_array_(rows, cols, this),
+	layout_(this)
 {
-	_layout.addWidget(&_well_array);
-	setLayout(&_layout);
+	layout_.addWidget(&well_array_);
+	setLayout(&layout_);
 
-	connect(&_well_array, SIGNAL(selected(int, int)),
+	connect(&well_array_, SIGNAL(selected(int, int)),
 		this, SIGNAL(selected(int, int)));
-	connect(&_well_array, SIGNAL(selected(int, int)),
+	connect(&well_array_, SIGNAL(selected(int, int)),
 		this, SLOT(colour_selected(int, int)));
 }
 
-QWellArray& ColourPopup::well_array()
+WellArray& ColourPopup::well_array()
 {
-	return _well_array;
+	return well_array_;
 }
 
 void ColourPopup::colour_selected(int, int)
@@ -47,5 +46,5 @@ void ColourPopup::colour_selected(int, int)
 	close();
 }
 
-} // widgets
-} // pv
+}  // namespace widgets
+}  // namespace pv
